@@ -2,6 +2,13 @@ package Statistics::Distribution::Generator;
 
 use 5.010;
 
+BEGIN {
+  if ($] lt '5.012') {
+    use strict;
+    use warnings;
+  }
+}
+
 use overload (
   '0+' => '_render',
   '""' => '_render',
@@ -15,7 +22,7 @@ use List::AllUtils qw( reduce );
 use Exporter qw( import );
 use vars qw( $VERSION );
 
-$VERSION = '1.002';
+$VERSION = '1.003';
 
 sub logistic ();
 
@@ -350,7 +357,7 @@ functions
 
 =head1 VERSION
 
-Version 1.002
+Version 1.003
 
 =head1 SYNOPSIS
 
